@@ -44,7 +44,9 @@
 
 #include <nlohmann/json.hpp>
 
+#include <dwarfs/file_extents_iterable.h>
 #include <dwarfs/file_stat.h>
+#include <dwarfs/file_view.h>
 #include <dwarfs/fstypes.h>
 #include <dwarfs/reader/block_range.h>
 #include <dwarfs/reader/fsinfo_features.h>
@@ -57,7 +59,6 @@ struct vfs_stat;
 
 class history;
 class logger;
-class mmif;
 class os_access;
 class performance_monitor;
 
@@ -94,11 +95,10 @@ class filesystem_v2_lite {
       filesystem_options const& options,
       std::shared_ptr<performance_monitor const> const& perfmon = nullptr);
 
-  filesystem_v2_lite(logger& lgr, os_access const& os,
-                     std::shared_ptr<mmif> mm);
+  filesystem_v2_lite(logger& lgr, os_access const& os, file_view const& mm);
 
   filesystem_v2_lite(
-      logger& lgr, os_access const& os, std::shared_ptr<mmif> mm,
+      logger& lgr, os_access const& os, file_view const& mm,
       filesystem_options const& options,
       std::shared_ptr<performance_monitor const> const& perfmon = nullptr);
 
@@ -188,6 +188,15 @@ class filesystem_v2_lite {
     return lite_->open(std::move(entry), ec);
   }
 
+  file_off_t seek(uint32_t inode, file_off_t offset, seek_whence whence) const {
+    return lite_->seek(inode, offset, whence);
+  }
+
+  file_off_t seek(uint32_t inode, file_off_t offset, seek_whence whence,
+                  std::error_code& ec) const {
+    return lite_->seek(inode, offset, whence, ec);
+  }
+
   std::string read_string(uint32_t inode) const {
     return lite_->read_string(inode);
   }
@@ -304,6 +313,8 @@ class filesystem_v2_lite {
 
   bool has_symlinks() const { return lite_->has_symlinks(); }
 
+  bool has_sparse_files() const { return lite_->has_sparse_files(); }
+
   nlohmann::json get_inode_info(inode_view entry) const {
     return lite_->get_inode_info(std::move(entry));
   }
@@ -379,6 +390,10 @@ class filesystem_v2_lite {
     virtual void statvfs(vfs_stat* stbuf) const = 0;
     virtual int open(inode_view entry) const = 0;
     virtual int open(inode_view entry, std::error_code& ec) const = 0;
+    virtual file_off_t
+    seek(uint32_t inode, file_off_t offset, seek_whence whence) const = 0;
+    virtual file_off_t seek(uint32_t inode, file_off_t offset,
+                            seek_whence whence, std::error_code& ec) const = 0;
     virtual std::string read_string(uint32_t inode) const = 0;
     virtual std::string
     read_string(uint32_t inode, std::error_code& ec) const = 0;
@@ -422,6 +437,7 @@ class filesystem_v2_lite {
     virtual void set_cache_tidy_config(cache_tidy_config const& cfg) = 0;
     virtual size_t num_blocks() const = 0;
     virtual bool has_symlinks() const = 0;
+    virtual bool has_sparse_files() const = 0;
     virtual nlohmann::json get_inode_info(inode_view entry) const = 0;
     virtual nlohmann::json
     get_inode_info(inode_view entry, size_t max_chunks) const = 0;
@@ -463,23 +479,23 @@ class filesystem_v2 final : public filesystem_v2_lite {
       filesystem_options const& options,
       std::shared_ptr<performance_monitor const> const& perfmon = nullptr);
 
-  filesystem_v2(logger& lgr, os_access const& os, std::shared_ptr<mmif> mm);
+  filesystem_v2(logger& lgr, os_access const& os, file_view const& mm);
 
   filesystem_v2(
-      logger& lgr, os_access const& os, std::shared_ptr<mmif> mm,
+      logger& lgr, os_access const& os, file_view const& mm,
       filesystem_options const& options,
       std::shared_ptr<performance_monitor const> const& perfmon = nullptr);
 
   static int
-  identify(logger& lgr, os_access const& os, std::shared_ptr<mmif> mm,
+  identify(logger& lgr, os_access const& os, file_view const& mm,
            std::ostream& output, int detail_level = 0, size_t num_readers = 1,
            bool check_integrity = false, file_off_t image_offset = 0);
 
-  static std::optional<std::span<uint8_t const>>
-  header(std::shared_ptr<mmif> mm);
+  static std::optional<file_extents_iterable>
+  header(logger& lgr, file_view const& mm);
 
-  static std::optional<std::span<uint8_t const>>
-  header(std::shared_ptr<mmif> mm, file_off_t image_offset);
+  static std::optional<file_extents_iterable>
+  header(logger& lgr, file_view const& mm, file_off_t image_offset);
 
   int check(filesystem_check_level level, size_t num_threads = 0) const;
 
@@ -490,7 +506,7 @@ class filesystem_v2 final : public filesystem_v2_lite {
   nlohmann::json metadata_as_json() const;
   std::string serialize_metadata_as_json(bool simple) const;
 
-  std::optional<std::span<uint8_t const>> header() const;
+  std::optional<file_extents_iterable> header() const;
 
   history const& get_history() const;
 
@@ -511,7 +527,7 @@ class filesystem_v2 final : public filesystem_v2_lite {
     virtual nlohmann::json info_as_json(fsinfo_options const& opts) const = 0;
     virtual nlohmann::json metadata_as_json() const = 0;
     virtual std::string serialize_metadata_as_json(bool simple) const = 0;
-    virtual std::optional<std::span<uint8_t const>> header() const = 0;
+    virtual std::optional<file_extents_iterable> header() const = 0;
     virtual history const& get_history() const = 0;
     virtual std::unique_ptr<thrift::metadata::metadata>
     thawed_metadata() const = 0;
